##  Further options for modeling Processes
Besides the SAP Signavio integration, the Resource tab on the Process Fact Sheet allows you to add diagrams that were created in LeanIX and also links that lead to diagrams you built in Lucidchart, Visio or other 3rd party tools, which provides another option for modeling processes.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b3b847a441014aa70cfa7e4fda0cc_LowRes.png)
YesNo
Send
